import React, { useEffect, useState } from "react";
import Footer from "./PageComponents/footer";
import Header from "./PageComponents/header";
import TabsContainer from "./Tabs/container";
import TimeSeries from "./Graphs/timeserie";
import BarChart from "./Graphs/barchart";
import PieChart from "./Graphs/piechart";
import Head from "next/head";

export default function Graphs() {

    const [averagePriceData, setAveragePriceData] = useState<any[]>([]);
    const [salesData, setSalesData] = useState<any[]>([]);

    const fetchAveragePriceData = async () => {
        const response = await fetch(`https://localhost/average_price_per_month?page=1`, {
            method: 'GET',
            headers: {
                'Content-Type': 'application/json',
            },
        });

        if (!response.ok) return console.log('Data not found !');
        const data = await response.json();
        const res = data['hydra:member'].map((v: any) => {
            return {
                x: v.month,
                y: v.averagePrice
            }
        });
        setAveragePriceData(res);
    }

    useEffect(() => {
        fetchAveragePriceData();
        console.log(averagePriceData)
    }, [averagePriceData]);


    // Put function to fetch data here
    // Default data for testing code
    const data1 = [
        { x: 0, y: 10 },
        { x: 1, y: 20 },
        { x: 2, y: 30 },
        { x: 3, y: 40 },
        { x: 4, y: 50 },
    ];
    const data2 = [10, 20, 30, 40, 50];
    const data3 = [
        { label: 'A', value: 10 },
        { label: 'B', value: 20 },
        { label: 'C', value: 30 },
        { label: 'D', value: 40 },
    ];
    const width = 500;
    const height = 300;

    // Component in each tab
    const tabs = [
        <TimeSeries key={0} tabLabel="Série temporelle" width={width} height={height} data={averagePriceData} />,
        <BarChart key={1} tabLabel="Diagramme à barre" width={width} height={height} data={data2} />,
        <PieChart key={2} tabLabel="Diagramme circulaire" width={width} height={height} data={data3} />
    ];

    return (
        <>
            <Head>
                <title>Graphs</title>
            </Head>
            <Header />
            <TabsContainer tabs={tabs} />
            <Footer />
        </>
    )
};